@@ -25,10 +25,20 @@
 #include "ns3/yans-wifi-channel.h"
 #include "ns3/yans-wifi-helper.h"
 
+/**
+ * @file
+ * @ingroup wifi
+ * WiFi multirate experiment.
+ */
+
 using namespace ns3;
 
 NS_LOG_COMPONENT_DEFINE("multirate");
 
+/** Unnamed namespace, to disambiguate class Experiment. */
+namespace
+{
+
 /**
  * WiFi multirate experiment class.
  *
@@ -429,7 +439,7 @@ Experiment::SendMultiDestinations(Ptr<Node> sender, NodeContainer c)
  * @param server Server node.
  * @return a string with the nodes data and positions
  */
-static inline std::string
+inline std::string
 PrintPosition(Ptr<Node> client, Ptr<Node> server)
 {
     Vector serverPos = server->GetObject<MobilityModel>()->GetPosition();
@@ -680,6 +690,8 @@ Experiment::CommandSetup(int argc, char** argv)
     return true;
 }
 
+} // unnamed namespace
+
 int
 main(int argc, char* argv[])
 {
