@@ -11,7 +11,6 @@
 #include "assert.h"
 #include "attribute-helper.h"
 #include "attribute.h"
-#include "event-id.h"
 #include "int64x64.h"
 #include "type-name.h"
 
@@ -391,6 +390,11 @@ class CORE_EXPORT Time
         return ToDouble(Time::MIN);
     }
 
+    /**
+     * @copydoc GetYears()
+     * @hidecaller
+     * @hideref
+     */
     inline double GetSeconds() const
     {
         return ToDouble(Time::S);
@@ -645,6 +649,8 @@ class CORE_EXPORT Time
      *
      * @param [in] unit The unit to use.
      * @return The Time with embedded unit.
+     * @hidecaller
+     * @hideref
      */
     TimeWithUnit As(const Unit unit = Time::AUTO) const;
 
@@ -771,6 +777,15 @@ class CORE_EXPORT Time
      */
     static bool StaticInit();
 
+    /**
+     * Spaceship comparison operator. All the other comparison operators
+     * are automatically generated from this one.
+     *
+     * @param other Time to compare to this one
+     * @returns The result of the comparison.
+     */
+    constexpr std::strong_ordering operator<=>(const Time& other) const = default;
+
   private:
     /**
      * @cond HIDE_FROM_DOXYGEN
@@ -805,21 +820,6 @@ class CORE_EXPORT Time
      */
     static void ConvertTimes(const Unit unit);
 
-    // Operator and related functions which need access
-
-    /**
-     * @name Comparison operators
-     * @{
-     */
-    friend bool operator==(const Time& lhs, const Time& rhs);
-    friend bool operator!=(const Time& lhs, const Time& rhs);
-    friend bool operator<=(const Time& lhs, const Time& rhs);
-    friend bool operator>=(const Time& lhs, const Time& rhs);
-    friend bool operator<(const Time& lhs, const Time& rhs);
-    friend bool operator>(const Time& lhs, const Time& rhs);
-    friend bool operator<(const Time& time, const EventId& event);
-    /**@}*/ // Comparison operators
-
     /**
      * @name Arithmetic operators
      * @{
@@ -890,107 +890,6 @@ typedef void (*Time)(Time oldValue, Time newValue);
  */
 static bool g_TimeStaticInit [[maybe_unused]] = Time::StaticInit();
 
-/**
- * Equality operator for Time.
- * @param [in] lhs The first value
- * @param [in] rhs The second value
- * @returns \c true if the two input values are equal.
- */
-inline bool
-operator==(const Time& lhs, const Time& rhs)
-{
-    return lhs.m_data == rhs.m_data;
-}
-
-/**
- * Inequality operator for Time.
- * @param [in] lhs The first value
- * @param [in] rhs The second value
- * @returns \c true if the two input values not are equal.
- */
-inline bool
-operator!=(const Time& lhs, const Time& rhs)
-{
-    return lhs.m_data != rhs.m_data;
-}
-
-/**
- * Less than or equal operator for Time.
- * @param [in] lhs The first value
- * @param [in] rhs The second value
- * @returns \c true if the first input value is less than or equal to the second input value.
- */
-inline bool
-operator<=(const Time& lhs, const Time& rhs)
-{
-    return lhs.m_data <= rhs.m_data;
-}
-
-/**
- * Greater than or equal operator for Time.
- * @param [in] lhs The first value
- * @param [in] rhs The second value
- * @returns \c true if the first input value is greater than or equal to the second input value.
- */
-inline bool
-operator>=(const Time& lhs, const Time& rhs)
-{
-    return lhs.m_data >= rhs.m_data;
-}
-
-/**
- * Less than operator for Time.
- * @param [in] lhs The first value
- * @param [in] rhs The second value
- * @returns \c true if the first input value is less than the second input value.
- */
-inline bool
-operator<(const Time& lhs, const Time& rhs)
-{
-    return lhs.m_data < rhs.m_data;
-}
-
-/**
- * Greater than operator for Time.
- * @param [in] lhs The first value
- * @param [in] rhs The second value
- * @returns \c true if the first input value is greater than the second input value.
- */
-inline bool
-operator>(const Time& lhs, const Time& rhs)
-{
-    return lhs.m_data > rhs.m_data;
-}
-
-/**
- * Compare a Time to an EventId.
- *
- * This is useful when you have cached a previously scheduled event:
- *
- *     m_event = Schedule (...);
- *
- * and later you want to know the relationship between that event
- * and some other Time `when`:
- *
- *     if (when < m_event) ...
- *
- * @param [in] time The Time operand.
- * @param [in] event The EventId
- * @returns \c true if \p time is before (less than) the
- *          time stamp of the EventId.
- */
-inline bool
-operator<(const Time& time, const EventId& event)
-{
-    // Negative Time is less than any possible EventId, which are all >= 0.
-    if (time.m_data < 0)
-    {
-        return true;
-    }
-    // Time must be >= 0 so casting to unsigned is safe.
-    return static_cast<uint64_t>(time.m_data) < event.GetTs();
-}
-
 /**
  * Addition operator for Time.
  * @param [in] lhs The first value
@@ -1365,6 +1264,11 @@ Minutes(int64x64_t value)
     return Time::From(value, Time::MIN);
 }
 
+/**
+ * @copydoc Years()
+ * @hidecaller
+ * @hideref
+ */
 inline Time
 Seconds(double value)
 {
@@ -1377,6 +1281,11 @@ Seconds(int64x64_t value)
     return Time::From(value, Time::S);
 }
 
+/**
+ * @copydoc Years()
+ * @hidecaller
+ * @hideref
+ */
 inline Time
 MilliSeconds(uint64_t value)
 {
@@ -1389,6 +1298,11 @@ MilliSeconds(int64x64_t value)
     return Time::From(value, Time::MS);
 }
 
+/**
+ * @copydoc Years()
+ * @hidecaller
+ * @hideref
+ */
 inline Time
 MicroSeconds(uint64_t value)
 {
@@ -1401,6 +1315,11 @@ MicroSeconds(int64x64_t value)
     return Time::From(value, Time::US);
 }
 
+/**
+ * @copydoc Years()
+ * @hidecaller
+ * @hideref
+ */
 inline Time
 NanoSeconds(uint64_t value)
 {
