@@ -1006,6 +1006,13 @@ class NormalRandomVariable : public RandomVariableStream
      */
     double GetVariance() const;
 
+    /**
+     * @brief Returns the standard deviation value for the normal distribution returned by this RNG
+     * stream.
+     * @return The standard deviation value for the normal distribution returned by this RNG stream.
+     */
+    double GetStdDev() const;
+
     /**
      * @brief Returns the bound on values that can be returned by this RNG stream.
      * @return The bound on values that can be returned by this RNG stream.
@@ -1025,6 +1032,14 @@ class NormalRandomVariable : public RandomVariableStream
     /** @copydoc GetValue(double,double,double) */
     uint32_t GetInteger(uint32_t mean, uint32_t variance, uint32_t bound);
 
+    /**
+     * Set standard deviation of this normal distribution RNG stream.
+     * The deviation is squared and stored as variance, which can also be set
+     * via the variance attribute.
+     * @param [in] stdDev Standard deviation value for the normal distribution.
+     */
+    void SetStdDev(double stdDev);
+
     // Inherited
     double GetValue() override;
     using RandomVariableStream::GetInteger;
