@@ -13,6 +13,7 @@
 #include "attribute.h"
 #include "callback.h"
 #include "deprecated.h"
+#include "event-id.h"
 #include "hash.h"
 #include "trace-source-accessor.h"
 
@@ -132,6 +133,8 @@ class TypeId
      *
      * This method cannot fail: it will crash if the input
      * name is not a valid TypeId name.
+     *
+     * @hidecaller
      */
     static TypeId LookupByName(std::string name);
     /**
@@ -244,6 +247,7 @@ class TypeId
      * Get the name.
      *
      * @returns The name of this interface.
+     * @hidecaller
      */
     std::string GetName() const;
 
@@ -326,6 +330,8 @@ class TypeId
      *
      * Record in this TypeId which TypeId is the TypeId
      * of the base class of the subclass.
+     *
+     * @hidecaller
      */
     TypeId SetParent(TypeId tid);
     /**
@@ -336,6 +342,8 @@ class TypeId
      *
      * Record in this TypeId which TypeId is the TypeId
      * of the base class of the subclass.
+     *
+     * @hidecaller
      */
     template <typename T>
     TypeId SetParent();
