@@ -22,7 +22,6 @@
 
 #include <cmath>
 #include <ctime>
-#include <fstream>
 #include <gsl/gsl_cdf.h>
 #include <gsl/gsl_histogram.h>
 #include <gsl/gsl_randist.h>
@@ -739,6 +738,23 @@ NormalTestCase::DoRun()
     double expectedMean = mean;
     double expectedRms = mean / std::sqrt(variance * N_MEASUREMENTS);
 
+    // Test that values have approximately the right mean value.
+    NS_TEST_ASSERT_MSG_EQ_TOL(valueMean,
+                              expectedMean,
+                              expectedRms * TOLERANCE,
+                              "Wrong mean value.");
+
+    // Repeat test when setting via stddev attribute instead of variance
+    x->SetStdDev(sqrt(variance));
+
+    // Calculate the mean of these values.
+    valueMean = Average(x);
+
+    // The expected value for the mean of the values returned by a
+    // normally distributed random variable is equal to mean.
+    expectedMean = mean;
+    expectedRms = mean / std::sqrt(variance * N_MEASUREMENTS);
+
     // Test that values have approximately the right mean value.
     NS_TEST_ASSERT_MSG_EQ_TOL(valueMean,
                               expectedMean,
@@ -2888,7 +2904,7 @@ BinomialAntitheticTestCase::DoRun()
 }
 
 /**
- * @ingroup rng-test
+ * @ingroup rng-tests
  * @ingroup tests
  *
  * @brief Test the Shuffle function
