@@ -343,10 +343,17 @@ CarrierAggregationConfigTestCase::DoRun()
         lteHelper->SetEnbDeviceAttribute("UlEarfcn", UintegerValue(configuration.m_ulEarfcn));
         lteHelper->SetUeDeviceAttribute("DlEarfcn", UintegerValue(configuration.m_dlEarfcn));
         enbDevs.Add(lteHelper->InstallEnbDevice(enbNodes.Get(i)));
-        lteHelper->AssignStreams(enbDevs, stream);
         ueDevs.Add(lteHelper->InstallUeDevice(ueNodes.Get(i)));
-        lteHelper->AssignStreams(ueDevs, stream);
     }
+    // Call AssignStreams in the EpcHelper only once by setting 'assignEpcStreams' only once
+    // Then, increment the stream value by 1000 (a magic number that should ensure that there
+    // are no overlapping stream assignments) each time that AssignStreams is called,
+    // to lessen the possibility that random variable stream assignment changes propagate
+    // to other objects.
+    lteHelper->AssignStreams(enbDevs, stream, false);
+    stream += 1000;
+    lteHelper->AssignStreams(ueDevs, stream, true);
+    stream += 1000;
 
     // Calculate the DlBandwidth, UlBandwidth, DlEarfcn and UlEarfcn to which the values from UE RRC
     // would be compared
