@@ -296,10 +296,17 @@ LteRadioLinkFailureTestCase::DoRun()
     NetDeviceContainer ueDevs;
 
     int64_t randomStream = 1;
+    // Call AssignStreams in the EpcHelper only once by setting 'assignEpcStreams' only once
+    // Then, increment the stream value by 1000 (a magic number that should ensure that there
+    // are no overlapping stream assignments) each time that AssignStreams is called,
+    // to lessen the possibility that random variable stream assignment changes propagate
+    // to other objects.
     enbDevs = lteHelper->InstallEnbDevice(enbNodes);
-    randomStream += lteHelper->AssignStreams(enbDevs, randomStream);
+    lteHelper->AssignStreams(enbDevs, randomStream, false);
+    randomStream += 1000;
     ueDevs = lteHelper->InstallUeDevice(ueNodes);
-    randomStream += lteHelper->AssignStreams(ueDevs, randomStream);
+    lteHelper->AssignStreams(ueDevs, randomStream, true);
+    randomStream += 1000;
 
     // Install the IP stack on the UEs
     internet.Install(ueNodes);
@@ -463,7 +470,6 @@ LteRadioLinkFailureTestCase::CheckConnected(Ptr<NetDevice> ueDevice, NetDeviceCo
 
     UeManager::State ueManagerState = ueManager->GetState();
     NS_TEST_ASSERT_MSG_EQ(ueManagerState, UeManager::CONNECTED_NORMALLY, "Wrong UeManager state!");
-    NS_ASSERT_MSG(ueManagerState == UeManager::CONNECTED_NORMALLY, "Wrong UeManager state!");
 
     uint16_t ueCellId = ueRrc->GetCellId();
     uint16_t enbCellId = enbLteDevice->GetCellId();
