@@ -264,7 +264,13 @@ LteX2HandoverTestCase::DoRun()
 
     NetDeviceContainer enbDevices;
     enbDevices = m_lteHelper->InstallEnbDevice(enbNodes);
-    stream += m_lteHelper->AssignStreams(enbDevices, stream);
+    // Call AssignStreams in the EpcHelper only once by setting 'assignEpcStreams' only once
+    // Then, increment the stream value by 1000 (a magic number that should ensure that there
+    // are no overlapping stream assignments) each time that AssignStreams is called,
+    // to lessen the possibility that random variable stream assignment changes propagate
+    // to other objects.
+    m_lteHelper->AssignStreams(enbDevices, stream, false);
+    stream += 1000;
     for (auto it = enbDevices.Begin(); it != enbDevices.End(); ++it)
     {
         Ptr<LteEnbRrc> enbRrc = (*it)->GetObject<LteEnbNetDevice>()->GetRrc();
@@ -273,7 +279,8 @@ LteX2HandoverTestCase::DoRun()
 
     NetDeviceContainer ueDevices;
     ueDevices = m_lteHelper->InstallUeDevice(ueNodes);
-    stream += m_lteHelper->AssignStreams(ueDevices, stream);
+    m_lteHelper->AssignStreams(ueDevices, stream, true);
+    stream += 1000;
 
     Ipv4Address remoteHostAddr;
     Ipv4StaticRoutingHelper ipv4RoutingHelper;
@@ -522,7 +529,6 @@ LteX2HandoverTestCase::CheckConnected(Ptr<NetDevice> ueDevice, Ptr<NetDevice> en
 
     UeManager::State ueManagerState = ueManager->GetState();
     NS_TEST_ASSERT_MSG_EQ(ueManagerState, UeManager::CONNECTED_NORMALLY, "Wrong UeManager state!");
-    NS_ASSERT_MSG(ueManagerState == UeManager::CONNECTED_NORMALLY, "Wrong UeManager state!");
 
     uint16_t ueCellId = ueRrc->GetCellId();
     uint16_t enbCellId = enbLteDevice->GetCellId();
