@@ -281,12 +281,6 @@ PbbTlvBlock::operator==(const PbbTlvBlock& other) const
     return true;
 }
 
-bool
-PbbTlvBlock::operator!=(const PbbTlvBlock& other) const
-{
-    return !(*this == other);
-}
-
 /* End PbbTlvBlock class */
 
 PbbAddressTlvBlock::PbbAddressTlvBlock()
@@ -520,12 +514,6 @@ PbbAddressTlvBlock::operator==(const PbbAddressTlvBlock& other) const
     return true;
 }
 
-bool
-PbbAddressTlvBlock::operator!=(const PbbAddressTlvBlock& other) const
-{
-    return !(*this == other);
-}
-
 /* End PbbAddressTlvBlock Class */
 
 PbbPacket::PbbPacket()
@@ -1001,12 +989,6 @@ PbbPacket::operator==(const PbbPacket& other) const
     return true;
 }
 
-bool
-PbbPacket::operator!=(const PbbPacket& other) const
-{
-    return !(*this == other);
-}
-
 /* End PbbPacket class */
 
 PbbMessage::PbbMessage()
@@ -1694,12 +1676,6 @@ PbbMessage::operator==(const PbbMessage& other) const
     return true;
 }
 
-bool
-PbbMessage::operator!=(const PbbMessage& other) const
-{
-    return !(*this == other);
-}
-
 /* End PbbMessage Class */
 
 PbbMessageIpv4::PbbMessageIpv4()
@@ -2415,12 +2391,6 @@ PbbAddressBlock::operator==(const PbbAddressBlock& other) const
     return m_addressTlvList == other.m_addressTlvList;
 }
 
-bool
-PbbAddressBlock::operator!=(const PbbAddressBlock& other) const
-{
-    return !(*this == other);
-}
-
 uint8_t
 PbbAddressBlock::GetPrefixFlags() const
 {
@@ -2972,12 +2942,6 @@ PbbTlv::operator==(const PbbTlv& other) const
     return true;
 }
 
-bool
-PbbTlv::operator!=(const PbbTlv& other) const
-{
-    return !(*this == other);
-}
-
 /* End PbbTlv Class */
 
 void
