@@ -208,20 +208,6 @@ FriisPropagationLossModel::GetFrequency() const
     return m_frequency;
 }
 
-double
-FriisPropagationLossModel::DbmToW(double dbm) const
-{
-    double mw = std::pow(10.0, dbm / 10.0);
-    return mw / 1000.0;
-}
-
-double
-FriisPropagationLossModel::DbmFromW(double w) const
-{
-    double dbm = std::log10(w * 1000.0) * 10.0;
-    return dbm;
-}
-
 double
 FriisPropagationLossModel::DoCalcRxPower(double txPowerDbm,
                                          Ptr<MobilityModel> a,
@@ -369,20 +355,6 @@ TwoRayGroundPropagationLossModel::GetFrequency() const
     return m_frequency;
 }
 
-double
-TwoRayGroundPropagationLossModel::DbmToW(double dbm) const
-{
-    double mw = std::pow(10.0, dbm / 10.0);
-    return mw / 1000.0;
-}
-
-double
-TwoRayGroundPropagationLossModel::DbmFromW(double w) const
-{
-    double dbm = std::log10(w * 1000.0) * 10.0;
-    return dbm;
-}
-
 double
 TwoRayGroundPropagationLossModel::DoCalcRxPower(double txPowerDbm,
                                                 Ptr<MobilityModel> a,
