@@ -24,11 +24,6 @@ class WifiPpdu;
 class WifiPsdu;
 class ErrorRateModel;
 
-/**
- * A map of the received power for each band
- */
-using RxPowerWattPerChannelBand = std::map<WifiSpectrumBandInfo, Watt_u>;
-
 /**
  * @ingroup wifi
  * @brief handles interference calculations
