@@ -172,7 +172,7 @@ WifiPhy::GetTypeId()
                           "Number of transmission power levels available between "
                           "TxPowerStart and TxPowerEnd included.",
                           UintegerValue(1),
-                          MakeUintegerAccessor(&WifiPhy::m_nTxPower),
+                          MakeUintegerAccessor(&WifiPhy::m_nTxPowerLevels),
                           MakeUintegerChecker<uint8_t>())
             .AddAttribute("TxPowerEnd",
                           "Maximum available transmission level (dBm).",
@@ -502,7 +502,7 @@ WifiPhy::RegisterListener(const std::shared_ptr<WifiPhyListener>& listener)
     if (IsInitialized())
     {
         // provide CCA busy information upon registering a PHY listener
-        SwitchMaybeToCcaBusy(nullptr);
+        SwitchMaybeToCcaBusy();
     }
 }
 
@@ -536,6 +536,10 @@ WifiPhy::SetCcaEdThreshold(dBm_u threshold)
 {
     NS_LOG_FUNCTION(this << threshold);
     m_ccaEdThreshold = threshold;
+    if (IsInitialized())
+    {
+        SwitchMaybeToCcaBusy();
+    }
 }
 
 dBm_u
@@ -595,16 +599,16 @@ WifiPhy::GetTxPowerEnd() const
 }
 
 void
-WifiPhy::SetNTxPower(uint8_t n)
+WifiPhy::SetNTxPowerLevels(uint8_t n)
 {
     NS_LOG_FUNCTION(this << +n);
-    m_nTxPower = n;
+    m_nTxPowerLevels = n;
 }
 
 uint8_t
-WifiPhy::GetNTxPower() const
+WifiPhy::GetNTxPowerLevels() const
 {
-    return m_nTxPower;
+    return m_nTxPowerLevels;
 }
 
 void
@@ -728,20 +732,19 @@ WifiPhy::SetWifiRadioEnergyModel(const Ptr<WifiRadioEnergyModel> wifiRadioEnergy
 dBm_u
 WifiPhy::GetPower(uint8_t powerLevel) const
 {
+    NS_ASSERT_MSG((powerLevel >= WIFI_MIN_TX_PWR_LEVEL) &&
+                      (powerLevel < (WIFI_MIN_TX_PWR_LEVEL + m_nTxPowerLevels)),
+                  "Invalid TX power level");
     NS_ASSERT(m_txPowerBase <= m_txPowerEnd);
-    NS_ASSERT(m_nTxPower > 0);
-    dBm_u dbm;
-    if (m_nTxPower > 1)
+    NS_ASSERT(m_nTxPowerLevels > 0);
+    NS_ASSERT((m_nTxPowerLevels > 1) || (m_txPowerBase == m_txPowerEnd));
+    auto power{m_txPowerBase};
+    if (m_nTxPowerLevels > 1)
     {
-        dbm = m_txPowerBase + dB_u{powerLevel * (m_txPowerEnd - m_txPowerBase) / (m_nTxPower - 1)};
+        power += dB_u{(powerLevel - WIFI_MIN_TX_PWR_LEVEL) * (m_txPowerEnd - m_txPowerBase) /
+                      (m_nTxPowerLevels - 1)};
     }
-    else
-    {
-        NS_ASSERT_MSG(m_txPowerBase == m_txPowerEnd,
-                      "cannot have TxPowerEnd != TxPowerStart with TxPowerLevels == 1");
-        dbm = m_txPowerBase;
-    }
-    return dbm;
+    return power;
 }
 
 Time
@@ -1307,7 +1310,10 @@ WifiPhy::DoChannelSwitch()
          * state are added to the event list and are employed later to figure
          * out the state of the medium after the switching.
          */
-        SwitchMaybeToCcaBusy(nullptr);
+        Simulator::Schedule(GetChannelSwitchDelay(), [=, this]() {
+            NS_LOG_DEBUG("Channel switching completed: update CCA indication");
+            SwitchMaybeToCcaBusy();
+        });
     }
 }
 
@@ -2218,6 +2224,10 @@ void
 WifiPhy::SwitchMaybeToCcaBusy(const Ptr<const WifiPpdu> ppdu /* = nullptr */)
 {
     NS_LOG_FUNCTION(this);
+    if (!IsStateIdle() && !IsStateCcaBusy())
+    {
+        return;
+    }
     GetLatestPhyEntity()->SwitchMaybeToCcaBusy(ppdu);
 }
 
