@@ -93,7 +93,7 @@ PowerRateAdaptationTest::ConfigureNode()
     /*
      * Configure power control parameters.
      */
-    phy->SetNTxPower(18);
+    phy->SetNTxPowerLevels(18);
     phy->SetTxPowerStart(dBm_u{0});
     phy->SetTxPowerEnd(dBm_u{17});
 
@@ -174,7 +174,7 @@ PowerRateAdaptationTest::TestParf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           54000000,
                           "PARF: Initial data rate wrong");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "PARF: Initial power level wrong");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "PARF: Initial power level wrong");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -194,7 +194,7 @@ PowerRateAdaptationTest::TestParf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           54000000,
                           "PARF: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 16, "PARF: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 17, "PARF: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -211,7 +211,7 @@ PowerRateAdaptationTest::TestParf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           54000000,
                           "PARF: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "PARF: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "PARF: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -233,7 +233,7 @@ PowerRateAdaptationTest::TestParf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           54000000,
                           "PARF: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 16, "PARF: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 17, "PARF: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -250,7 +250,7 @@ PowerRateAdaptationTest::TestParf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           54000000,
                           "PARF: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "PARF: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "PARF: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -268,7 +268,7 @@ PowerRateAdaptationTest::TestParf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           48000000,
                           "PARF: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "PARF: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "PARF: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -288,7 +288,7 @@ PowerRateAdaptationTest::TestParf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           54000000,
                           "PARF: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "PARF: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "PARF: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -305,7 +305,7 @@ PowerRateAdaptationTest::TestParf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           48000000,
                           "PARF: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "PARF: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "PARF: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -325,7 +325,7 @@ PowerRateAdaptationTest::TestParf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           54000000,
                           "PARF: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "PARF: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "PARF: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -345,7 +345,7 @@ PowerRateAdaptationTest::TestParf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           54000000,
                           "PARF: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 16, "PARF: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 17, "PARF: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -367,7 +367,7 @@ PowerRateAdaptationTest::TestParf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           54000000,
                           "PARF: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "PARF: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "PARF: Incorrect value of power level");
 
     Simulator::Destroy();
 }
@@ -419,7 +419,7 @@ PowerRateAdaptationTest::TestAparf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           54000000,
                           "APARF: Initial data rate wrong");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "APARF: Initial power level wrong");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "APARF: Initial power level wrong");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -440,7 +440,7 @@ PowerRateAdaptationTest::TestAparf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           54000000,
                           "APARF: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 16, "APARF: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 17, "APARF: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -457,7 +457,7 @@ PowerRateAdaptationTest::TestAparf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           54000000,
                           "APARF: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "APARF: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "APARF: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -477,7 +477,7 @@ PowerRateAdaptationTest::TestAparf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           54000000,
                           "APARF: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 16, "APARF: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 17, "APARF: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -498,7 +498,7 @@ PowerRateAdaptationTest::TestAparf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           54000000,
                           "APARF: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 15, "APARF: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 16, "APARF: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -518,7 +518,7 @@ PowerRateAdaptationTest::TestAparf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           54000000,
                           "APARF: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 0, "APARF: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 1, "APARF: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -535,7 +535,7 @@ PowerRateAdaptationTest::TestAparf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           54000000,
                           "Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 1, "Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 2, "Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -555,7 +555,7 @@ PowerRateAdaptationTest::TestAparf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           54000000,
                           "APARF: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "APARF: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "APARF: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -573,7 +573,7 @@ PowerRateAdaptationTest::TestAparf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           48000000,
                           "Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -593,7 +593,7 @@ PowerRateAdaptationTest::TestAparf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           48000000,
                           "APARF: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 16, "APARF: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 17, "APARF: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -615,7 +615,7 @@ PowerRateAdaptationTest::TestAparf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           48000000,
                           "APARF: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 7, "APARF: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 8, "APARF: Incorrect value of power level");
 
     for (int i = 0; i < 3; i++)
     {
@@ -629,7 +629,7 @@ PowerRateAdaptationTest::TestAparf()
     NS_TEST_ASSERT_MSG_EQ(mode.GetDataRate(txVector.GetChannelWidth()),
                           54000000,
                           "APARF: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "APARF: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "APARF: Incorrect value of power level");
 
     Simulator::Destroy();
 }
@@ -714,7 +714,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         6000000,
         "RRPAA: Initial data rate wrong"); // 802.11a minimal rate is 6Mbps
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "RRPAA: Initial power level wrong");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "RRPAA: Initial power level wrong");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -739,7 +739,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         6000000,
         "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "RRPAA: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "RRPAA: Incorrect value of power level");
 
     /**
      * Test that 7 is enough.
@@ -754,7 +754,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         9000000,
         "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "RRPAA: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "RRPAA: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -775,7 +775,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         9000000,
         "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "RRPAA: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "RRPAA: Incorrect value of power level");
 
     manager->ReportDataFailed(mpdu);
 
@@ -787,7 +787,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         6000000,
         "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "RRPAA: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "RRPAA: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -808,7 +808,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         9000000,
         "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "RRPAA: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "RRPAA: Incorrect value of power level");
 
     for (int i = 0; i < 10; i++)
     {
@@ -823,7 +823,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         12000000,
         "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "RRPAA: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "RRPAA: Incorrect value of power level");
 
     for (int i = 0; i < 13; i++)
     {
@@ -838,7 +838,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         18000000,
         "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "RRPAA: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "RRPAA: Incorrect value of power level");
 
     for (int i = 0; i < 19; i++)
     {
@@ -853,7 +853,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         24000000,
         "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "RRPAA: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "RRPAA: Incorrect value of power level");
 
     for (int i = 0; i < 23; i++)
     {
@@ -868,7 +868,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         36000000,
         "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "RRPAA: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "RRPAA: Incorrect value of power level");
 
     for (int i = 0; i < 33; i++)
     {
@@ -883,7 +883,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         48000000,
         "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "RRPAA: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "RRPAA: Incorrect value of power level");
 
     for (int i = 0; i < 43; i++)
     {
@@ -898,7 +898,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         54000000,
         "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "RRPAA: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "RRPAA: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -921,7 +921,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         54000000,
         "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "RRPAA: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "RRPAA: Incorrect value of power level");
 
     manager->ReportDataOk(mpdu, 0, ackMode, 0, txVector);
 
@@ -933,7 +933,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         54000000,
         "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 16, "RRPAA: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 17, "RRPAA: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -955,7 +955,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         54000000,
         "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 0, "RRPAA: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 1, "RRPAA: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -976,7 +976,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         54000000,
         "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 1, "RRPAA: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 2, "RRPAA: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -997,7 +997,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         54000000,
         "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "RRPAA: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "RRPAA: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -1018,7 +1018,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         48000000,
         "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "RRPAA: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "RRPAA: Incorrect value of power level");
 
     /*
      * Now 11 failures are needed to decrease rate again.
@@ -1037,7 +1037,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         36000000,
         "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 17, "RRPAA: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "RRPAA: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -1056,6 +1056,21 @@ PowerRateAdaptationTest::TestRrpaa()
     mode = txVector.GetMode();
     power = (int)txVector.GetTxPowerLevel();
 
+    NS_TEST_ASSERT_MSG_EQ(
+        mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
+        36000000,
+        "RRPAA: Incorrect vale of data rate");
+    NS_TEST_ASSERT_MSG_EQ(power, 18, "RRPAA: Incorrect value of power level");
+
+    for (int i = 0; i < 5; i++)
+    {
+        manager->ReportDataFailed(mpdu);
+    }
+
+    txVector = manager->GetDataTxVector(packetHeader, dev->GetPhy()->GetChannelWidth());
+    mode = txVector.GetMode();
+    power = (int)txVector.GetTxPowerLevel();
+
     NS_TEST_ASSERT_MSG_EQ(
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         36000000,
@@ -1075,22 +1090,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         36000000,
         "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 16, "RRPAA: Incorrect value of power level");
-
-    for (int i = 0; i < 5; i++)
-    {
-        manager->ReportDataFailed(mpdu);
-    }
-
-    txVector = manager->GetDataTxVector(packetHeader, dev->GetPhy()->GetChannelWidth());
-    mode = txVector.GetMode();
-    power = (int)txVector.GetTxPowerLevel();
-
-    NS_TEST_ASSERT_MSG_EQ(
-        mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
-        36000000,
-        "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 16, "RRPAA: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 17, "RRPAA: Incorrect value of power level");
 
     for (int i = 0; i < 25; i++)
     {
@@ -1105,7 +1105,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         36000000,
         "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 15, "RRPAA: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 16, "RRPAA: Incorrect value of power level");
 
     //-----------------------------------------------------------------------------------------------------
 
@@ -1134,7 +1134,7 @@ PowerRateAdaptationTest::TestRrpaa()
         mode.GetDataRate(txVector.GetChannelWidth(), txVector.GetGuardInterval(), 1),
         36000000,
         "RRPAA: Incorrect vale of data rate");
-    NS_TEST_ASSERT_MSG_EQ(power, 0, "RRPAA: Incorrect value of power level");
+    NS_TEST_ASSERT_MSG_EQ(power, 1, "RRPAA: Incorrect value of power level");
 
     Simulator::Stop(Seconds(10));
 
